@@ -531,7 +531,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		}
 		else
 		{
-			params.corners    = CR_CORNER_ALL;
+			params.corners = CR_CORNER_ALL;
 			params.enable_glow = TRUE;
 		}
 		
@@ -607,7 +607,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 			slider.horizontal = TRUE;
 		else if (CHECK_HINT (GE_HINT_VSCALE))
 			slider.horizontal = FALSE;
-		else /* Fallback based on the size  ... */
+		else /* Fallback based on the size... */
 			slider.horizontal = width >= height;
 		
 		STYLE_FUNCTION(draw_scale_trough) (cr, &clearlooks_style->colors,
@@ -1222,7 +1222,7 @@ clearlooks_style_init_from_rc (GtkStyle * style,
 	clearlooks_parent_class->init_from_rc (style, rc_style);
 	
 	g_assert ((CLEARLOOKS_RC_STYLE (rc_style)->style >= 0) && (CLEARLOOKS_RC_STYLE (rc_style)->style < CL_NUM_STYLES));
-	clearlooks_style->style		= CLEARLOOKS_RC_STYLE (rc_style)->style;
+	clearlooks_style->style               = CLEARLOOKS_RC_STYLE (rc_style)->style;
 	
 	clearlooks_style->menubarstyle        = CLEARLOOKS_RC_STYLE (rc_style)->menubarstyle;
 	clearlooks_style->toolbarstyle        = CLEARLOOKS_RC_STYLE (rc_style)->toolbarstyle;
@@ -1257,14 +1257,14 @@ clearlooks_style_realize (GtkStyle * style)
 
 	for (i = 0; i < 9; i++)
 	{
-		ge_shade_color(&bg_normal, (shades[i]-0.7) * contrast + 0.7, &clearlooks_style->colors.shade[i]);
+		ge_shade_color (&bg_normal, (shades[i]-0.7) * contrast + 0.7, &clearlooks_style->colors.shade[i]);
 	}
 
 	ge_gdk_color_to_cairo (&style->bg[GTK_STATE_SELECTED], &spot_color);
 
-	ge_shade_color(&spot_color, 1.42, &clearlooks_style->colors.spot[0]);
-	ge_shade_color(&spot_color, 1.05, &clearlooks_style->colors.spot[1]);
-	ge_shade_color(&spot_color, 0.65, &clearlooks_style->colors.spot[2]);
+	ge_shade_color (&spot_color, 1.25, &clearlooks_style->colors.spot[0]);
+	ge_shade_color (&spot_color, 1.05, &clearlooks_style->colors.spot[1]);
+	ge_shade_color (&spot_color, 0.65, &clearlooks_style->colors.spot[2]);
 
 	for (i=0; i<5; i++)
 	{
@@ -1312,6 +1312,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 		}
 	}
 
+	focus.has_color = FALSE;
 	focus.interior = FALSE;
 	focus.line_width = 1;
 	dash_list = NULL;
@@ -1321,6 +1322,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 		gtk_widget_style_get (widget,
 		                      "focus-line-width", &focus.line_width,
 		                      "focus-line-pattern", &dash_list,
+		                      "focus-padding", &focus.padding,
 		                      "interior-focus", &focus.interior,
 		                      NULL);
 	}
@@ -1393,7 +1395,10 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 	}
 	else
 	{
-		focus.type = CL_FOCUS_LABEL; /* Let's call it "LABEL" :) */
+		if (CHECK_HINT (GE_HINT_TREEVIEW))
+			focus.type = CL_FOCUS_TREEVIEW; /* Let's call it "LABEL" :) */
+		else
+			focus.type = CL_FOCUS_LABEL;
 	}
 	
 	/* Focus color */
@@ -1403,7 +1408,7 @@ clearlooks_style_draw_focus (GtkStyle *style, GdkWindow *window, GtkStateType st
 		focus.has_color = TRUE;
 	}
 	else
-		focus.color = colors->spot[1];
+		focus.color = colors->bg[GTK_STATE_SELECTED];
 
 	STYLE_FUNCTION(draw_focus) (cr, colors, &params, &focus, x, y, width, height);
 
